@@ -104,7 +104,10 @@ def _loads_kvn(string):
         if man["duration"].total_seconds() == 0:
             orb.maneuvers.append(
                 ImpulsiveMan(
-                    man["date"], man["dv"], frame=man["frame"], comment=man["comment"],
+                    man["date"],
+                    man["dv"],
+                    frame=man["frame"],
+                    comment=man["comment"],
                 )
             )
         else:
@@ -369,7 +372,7 @@ def _dumps_xml(data, **kwargs):
         for i, a in enumerate(elems):
             for j, b in enumerate(elems[: i + 1]):
                 x = ET.SubElement(cov, "C{a}_{b}".format(a=a, b=b))
-                x.text = "{:0.16e}".format(cart.cov[i, j] / 1e6)
+                x.text = "{:0.12e}".format(cart.cov[i, j] / 1e6)
 
     if cart.maneuvers:
         for man in cart.maneuvers:
